/***************************************************************************
                          main.cpp  -  description
                          ------------------------
    copyright            : (C) 2000 by Torsten Henschel
    email                : henschel@fh-brandenburg.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <kapp.h>

#include <kpopup.h>

int main(int argc, char **argv)
{
 KApplication a(argc, argv, "kpopup");
 if(argc != 1)
   {
    a.beep();
   }
// if (a.isRestored())
//		RESTORE(Komba)
//	else {
 Kpopup *w = new Kpopup(argc, argv);
 w -> setGeometry(100, 100, 400, 400);
 w -> setCaption("Kpopup");
 if(argc != 1)
   {
    a.beep();
   }
 a.setMainWidget(w);
 w -> show();
//	}
 return a.exec();
}
